Core modules
============

The following modules of Kwant are used directly most frequently.

.. toctree::
   :maxdepth: 1

   kwant
   kwant.builder
   kwant.lattice
   kwant.plotter
   kwant.solvers
   kwant.operator
   kwant.physics

Other modules
=============

The following modules provide functionality for special applications.

.. toctree::
   :maxdepth: 1

   kwant.digest
   kwant.rmt
   kwant.kpm
   kwant.continuum
   kwant.wraparound
   kwant.qsymm

Modules mainly for internal use
===============================

The following modules contain functionality that is most often used only
internally by Kwant itself or by advanced users.

.. toctree::
   :maxdepth: 1

   kwant.system
   kwant.graph
   kwant.linalg
